
# Slot: directed


Whether to load the graph as directed or undirected.

URI: [https://w3id.org/neat/ensmallenRunConfig__directed](https://w3id.org/neat/ensmallenRunConfig__directed)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
